=======
Credits
=======

Development Lead
----------------

* John Preston
    * Github: https://github.com/johnpreston
    * Keybase: https://keybase.io/johnpreston78
    


Special thanks
--------------

* Harold Spencer
    Harold is an old friend of mine, who has agreed to be my guinea pig and keep my assumptions etc. in check to make
    this tool as relevant as possible and actually solve issues than trying to implement goodies features.
    
    * KeyBase: https://keybase.io/hspencer77
    * GitHub: https://github.com/hspencer77
